@@ -12,7 +12,7 @@ Usage::
     client: Route53RecoveryClusterClient = boto3.client("route53-recovery-cluster")
     ```
 """
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, Mapping, Sequence, Type
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -25,7 +25,7 @@ __all__ = ("Route53RecoveryClusterClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -43,7 +43,7 @@ class Exceptions:
 
 class Route53RecoveryClusterClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html)
     """
 
@@ -59,21 +59,21 @@ class Route53RecoveryClusterClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#can_paginate)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = None,
         ExpiresIn: int = 3600,
         HttpMethod: str = None,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#generate_presigned_url)
         """
 
@@ -83,7 +83,7 @@ class Route53RecoveryClusterClient(BaseClient):
         """
         Get the state for a routing control.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.get_routing_control_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.get_routing_control_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#get_routing_control_state)
         """
 
@@ -93,16 +93,16 @@ class Route53RecoveryClusterClient(BaseClient):
         """
         Set the state of the routing control to reroute traffic.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#update_routing_control_state)
         """
 
     def update_routing_control_states(
-        self, *, UpdateRoutingControlStateEntries: List["UpdateRoutingControlStateEntryTypeDef"]
+        self, *, UpdateRoutingControlStateEntries: Sequence["UpdateRoutingControlStateEntryTypeDef"]
     ) -> Dict[str, Any]:
         """
         Set multiple routing control states.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.41/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_states)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.43/reference/services/route53-recovery-cluster.html#Route53RecoveryCluster.Client.update_routing_control_states)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/client.html#update_routing_control_states)
         """
